@@ -203,9 +203,9 @@ compare_direntry_scores (gconstpointer a,
 	const struct ico_direntry_data *ib = b;
 
 	/* Backwards, so largest first */
-	if (ib->ImageScore > ia->ImageScore)
+	if (ib->ImageScore < ia->ImageScore)
 		return -1;
-	else if (ib->ImageScore < ia->ImageScore)
+	else if (ib->ImageScore > ia->ImageScore)
 		return 1;
 	return 0;
 }
@@ -610,6 +610,7 @@ gdk_pixbuf__ico_image_stop_load(gpointer data,
 {
 	struct ico_progressive_state *context =
 	    (struct ico_progressive_state *) data;
+	gboolean ret = TRUE;
 
         /* FIXME this thing needs to report errors if
          * we have unused image data
@@ -617,8 +618,16 @@ gdk_pixbuf__ico_image_stop_load(gpointer data,
 
 	g_return_val_if_fail(context != NULL, TRUE);
 
+	if (context->HeaderDone < context->HeaderSize) {
+		g_set_error_literal (error,
+				     GDK_PIXBUF_ERROR,
+				     GDK_PIXBUF_ERROR_CORRUPT_IMAGE,
+				     _("ICO image was truncated or incomplete."));
+		ret = FALSE;
+	}
+
 	context_free (context);
-        return TRUE;
+        return ret;
 }
 
 static void
@@ -941,6 +950,9 @@ gdk_pixbuf__ico_image_load_increment(gpointer data,
 				BytesToCopy = size;
 
 			if (BytesToCopy > 0) {
+				/* Should be non-NULL once the header is decoded, as below. */
+				g_assert (context->LineBuf != NULL);
+
 				memmove(context->LineBuf +
 				       context->LineDone, buf,
 				       BytesToCopy);
